==> apache-opennlp_1.9.4.orig.tar.gz: apache-opennlp-1.9.4-src/opennlp-tools/src/main/java/opennlp/tools/util/featuregen/PreviousTwoMapFeatureGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.util.featuregen;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * This {@link AdaptiveFeatureGenerator} generates features indicating the
 * outcome associated with two previously occuring words.
 */
public class PreviousTwoMapFeatureGenerator implements AdaptiveFeatureGenerator {

  private Map<String, String> previousMap = new HashMap<>();

  /**
   * Generates previous decision features for the token based on contents of the previous map.
   */
  public void createFeatures(List<String> features, String[] tokens, int index, String[] preds) {
    if (index > 0) {
      features.add("ppd=" + previousMap.get(tokens[index]) + "," +
          previousMap.get(tokens[index - 1]));
    }
  }

  public void updateAdaptiveData(String[] tokens, String[] outcomes) {
    for (int i = 0; i < tokens.length; i++) {
      previousMap.put(tokens[i], outcomes[i]);
    }
  }

  /**
   * Clears the previous map.
   */
  public void clearAdaptiveData() {
    previousMap.clear();
  }
}

==> apache-opennlp_2.3.2.orig.tar.gz: apache-opennlp-2.3.2-src/opennlp-tools/src/main/java/opennlp/tools/util/featuregen/PreviousTwoMapFeatureGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.util.featuregen;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * This {@link AdaptiveFeatureGenerator} generates features indicating the
 * outcome associated with two previously occurring words.
 */
public class PreviousTwoMapFeatureGenerator implements AdaptiveFeatureGenerator {

  private final Map<String, String> previousMap = new HashMap<>();

  /**
   * Generates previous decision features for the token based on contents of the previous map.
   */
  @Override
  public void createFeatures(List<String> features, String[] tokens, int index, String[] preds) {
    if (index > 0) {
      features.add("ppd=" + previousMap.get(tokens[index]) + "," +
          previousMap.get(tokens[index - 1]));
    }
  }

  @Override
  public void updateAdaptiveData(String[] tokens, String[] outcomes) {
    for (int i = 0; i < tokens.length; i++) {
      previousMap.put(tokens[i], outcomes[i]);
    }
  }
  
  @Override
  public void clearAdaptiveData() {
    previousMap.clear();
  }
}
